//
//  SOMAMoPubRewardedVideoAdapter.m
//  Smaato
//
//  Copyright © 2019 Smaato Inc. All rights reserved.￼
//  Licensed under the Smaato SDK License Agreement￼
//  https://www.smaato.com/sdk-license-agreement/
//

#import <iSoma/iSoma.h>
#import "SOMAMoPubRewardedVideoAdapter.h"

@interface SOMAMoPubRewardedVideoAdapter()<SOMAVideoAdControllerDelegate>
@property (nonatomic) SOMAVideoAdController *videoAdController;
@property (nonatomic) MPRewardedVideoReward *defaultReward;
@end

@implementation SOMAMoPubRewardedVideoAdapter

- (void)requestRewardedVideoWithCustomEventInfo:(NSDictionary *)info adMarkup:(NSString *)adMarkup {

    self.defaultReward = [[MPRewardedVideoReward alloc]
                          initWithCurrencyType:kMPRewardedVideoRewardCurrencyTypeUnspecified
                          amount:[[NSNumber alloc] initWithInt:1]];
    
    // Create video ad container
	self.videoAdController = [[SOMAVideoAdController alloc] init];
	self.videoAdController.delegate = self;

    // Apply ad settings
    self.videoAdController.adSettings.autoReloadEnabled = NO;
    [self extractPublisherAndAdSpaceIDFromParameters:info];
	
    dispatch_async(dispatch_get_main_queue(), ^{
        [self.videoAdController loadRewardedVideo];
    });
}

- (void)extractPublisherAndAdSpaceIDFromParameters:(NSDictionary*)parameters {
    if ([[parameters allKeys] containsObject:@"pub"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"pub"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisher"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisher"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherid"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisherid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherId"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherId"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"PublisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherID"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"PublisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherID"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Publisher"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"Publisher"] intValue];
    }
    
    if ([[parameters allKeys] containsObject:@"ad"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"ad"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspace"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceid"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspaceid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceId"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceId"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceID"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceID"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceID"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdSpaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceId"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdSpaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpace"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdSpace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Ad"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"Ad"] intValue];
    }
}

- (BOOL)hasAdAvailable {
	return [self.videoAdController isReady];
}

- (void)presentRewardedVideoFromViewController:(UIViewController *)viewController {
	if ([self.videoAdController isReady]) {
		[self.videoAdController show:viewController];
    } else {
        if ([self.delegate respondsToSelector:@selector(rewardedVideoDidFailToPlayForCustomEvent:error:)]) {
            NSError *error = [NSError errorWithDomain:@"SOMAMoPubRewardedVideoAdapter"
                                                 code:0
                                             userInfo:@{NSLocalizedDescriptionKey: @"Ad is not ready."}];
            [self.delegate rewardedVideoDidFailToPlayForCustomEvent:self error:error];
        }
    }
}

#pragma mark - SOMAVideoAdControllerDelegate
- (UIViewController*)somaRootViewController {
    return nil;
}

- (void)somaAdViewDidClick:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(rewardedVideoDidReceiveTapEventForCustomEvent:)]) {
        [self.delegate rewardedVideoDidReceiveTapEventForCustomEvent:self];
    }
}

- (void)somaVideoAdWillLoadAd:(SOMAVideoAdController *)adview {
    
}

- (void)somaVideoAdDidLoadAd:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(rewardedVideoDidLoadAdForCustomEvent:)]) {
        [self.delegate rewardedVideoDidLoadAdForCustomEvent:self];
    }
}

- (void)somaVideoAd:(SOMAVideoAdController*)adview didFailToReceiveAdWithError:(NSError *)error {
    if ([self.delegate respondsToSelector:@selector(rewardedVideoDidFailToLoadAdForCustomEvent:error:)]) {
        [self.delegate rewardedVideoDidFailToLoadAdForCustomEvent:self error:error];
    }
}

- (void)somaVideoAdWillEnterFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(rewardedVideoWillAppearForCustomEvent:)]) {
        [self.delegate rewardedVideoWillAppearForCustomEvent:self];
    }
}

- (void)somaVideoAdDidEnterFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(rewardedVideoDidAppearForCustomEvent:)]) {
        [self.delegate rewardedVideoDidAppearForCustomEvent:self];
    }
}

- (void)somaVideoAdWillExitFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(rewardedVideoWillDisappearForCustomEvent:)]) {
        [self.delegate rewardedVideoWillDisappearForCustomEvent:self];
    }
}

- (void)somaVideoAdDidExitFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(rewardedVideoDidDisappearForCustomEvent:)]) {
        [self.delegate rewardedVideoDidDisappearForCustomEvent:self];
    }
}

- (void)somaVideoAdWillLeaveApplicationFromAd:(SOMAVideoAdController*)adview {
    // From MoPub documentation:
    // Some third-party networks provide a "will leave application" callback instead of/in addition to a "user did click" callback.
    // You should call this method in response to either of those callbacks.
    if ([self.delegate respondsToSelector:@selector(rewardedVideoDidReceiveTapEventForCustomEvent:)]) {
        [self.delegate rewardedVideoDidReceiveTapEventForCustomEvent:self];
    }
    if ([self.delegate respondsToSelector:@selector(rewardedVideoWillLeaveApplicationForCustomEvent:)]) {
        [self.delegate rewardedVideoWillLeaveApplicationForCustomEvent:self];
    }
}

- (void)somaVideoAd:(SOMAVideoAdController *)adview didReceiveVideoAdEvent:(SOMAVideoAdTrackingEvent)event {
    if (event == SOMAVideoAdTrackingEventComplete) {
        if (self.delegate && [self.delegate respondsToSelector:@selector(rewardedVideoShouldRewardUserForCustomEvent:reward:)]) {
            [self.delegate rewardedVideoShouldRewardUserForCustomEvent:self reward:self.defaultReward];
        }
    }
}

@end
