//
//  SOMAMoPubVideoInterstitialAdapter.m
//  Smaato
//
//  Copyright © 2019 Smaato Inc. All rights reserved.￼
//  Licensed under the Smaato SDK License Agreement￼
//  https://www.smaato.com/sdk-license-agreement/
//

#import <iSoma/iSoma.h>
#import "SOMAMoPubVideoInterstitialAdapter.h"
#import "MoPub.h"

@interface SOMAMoPubVideoInterstitialAdapter ()<SOMAVideoAdControllerDelegate>
@property (nonatomic) SOMAVideoAdController* videoAdController;
@end

@implementation SOMAMoPubVideoInterstitialAdapter

- (void)requestInterstitialWithCustomEventInfo:(NSDictionary *)info adMarkup:(NSString *)adMarkup {
    
    // Create video ad container
	self.videoAdController = [[SOMAVideoAdController alloc] init];
	self.videoAdController.delegate = self;
	
    // Apply ad settings
    self.videoAdController.adSettings.type = SOMAAdTypeVideo;
    self.videoAdController.adSettings.autoReloadEnabled = NO;
    self.videoAdController.adSettings.videoAutocloseDisabled = YES;

    [self extractPublisherAndAdSpaceIDFromParameters:info];
    
    // Optional: Pass location information
    CLLocation* location =  [self.delegate location];
    if (location) {
        self.videoAdController.adSettings.longitude = location.coordinate.longitude;
        self.videoAdController.adSettings.latitude = location.coordinate.latitude;
    }
    
    // Optional: You can also set user profile targeting parameters by updating the `adView.adSettings.userProfile` object.
    // Please check the Smaato wiki for all available properties and further details.
    
    dispatch_async(dispatch_get_main_queue(), ^{
        [self.videoAdController load];
    });
}

- (void)extractPublisherAndAdSpaceIDFromParameters:(NSDictionary*)parameters {
    if ([[parameters allKeys] containsObject:@"pub"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"pub"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisher"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisher"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherid"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisherid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherId"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherId"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"PublisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherID"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"PublisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherID"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"publisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Publisher"]) {
        self.videoAdController.adSettings.publisherId=[parameters[@"Publisher"] intValue];
    }
    
    if ([[parameters allKeys] containsObject:@"ad"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"ad"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspace"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceid"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspaceid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceId"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceId"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceID"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceID"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"adspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceID"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdSpaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceId"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdSpaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpace"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"AdSpace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Ad"]) {
        self.videoAdController.adSettings.adSpaceId=[parameters[@"Ad"] intValue];
    }
}

- (void)showInterstitialFromRootViewController:(UIViewController *)rootViewController {
	if ([self.videoAdController isReady]) {
		[self.videoAdController show:rootViewController];
	}
}

#pragma mark - SOMAVideoAdControllerDelegate
- (UIViewController*)somaRootViewController {
    return nil;
}

- (void)somaAdViewDidClick:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEventDidReceiveTapEvent:)]) {
        [self.delegate interstitialCustomEventDidReceiveTapEvent:self];
    }
}

- (void)somaVideoAdWillLoadAd:(SOMAVideoAdController *)adview {
    
}

- (void)somaVideoAdDidLoadAd:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEvent:didLoadAd:)]) {
        [self.delegate interstitialCustomEvent:self didLoadAd:nil];
    }
}

- (void)somaVideoAd:(SOMAVideoAdController*)adview didFailToReceiveAdWithError:(NSError *)error {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEvent:didFailToLoadAdWithError:)]) {
        [self.delegate interstitialCustomEvent:self didFailToLoadAdWithError:error];
    }
}

- (void)somaVideoAdWillEnterFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEventWillAppear:)]) {
        [self.delegate interstitialCustomEventWillAppear:self];
    }
}

- (void)somaVideoAdDidEnterFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEventDidAppear:)]) {
        [self.delegate interstitialCustomEventDidAppear:self];
    }
}

- (void)somaVideoAdWillExitFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEventWillDisappear:)]) {
        [self.delegate interstitialCustomEventWillDisappear:self];
    }
}

- (void)somaVideoAdDidExitFullscreen:(SOMAVideoAdController *)adview {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEventDidDisappear:)]) {
        [self.delegate interstitialCustomEventDidDisappear:self];
    }
}

- (void)somaVideoAdWillLeaveApplicationFromAd:(SOMAVideoAdController*)adview {
    if ([self.delegate respondsToSelector:@selector(interstitialCustomEventWillLeaveApplication:)]) {
        [self.delegate interstitialCustomEventWillLeaveApplication:self];
    }
}

- (void)somaVideoAd:(SOMAVideoAdController *)adview didReceiveVideoAdEvent:(SOMAVideoAdTrackingEvent)event {
    if (event == SOMAVideoAdTrackingEventComplete) {
        
    }
}

@end
